==> worlds_wl-0.0.0.tar.gz: worlds_wl-0.0.0/src/worlds/wl/docs/en_Wario_Land.md <==
# Wario Land 1

## Where is the settings page?

You can read through all the settings and generate a YAML [here](../player-settings).

## Important things to note

- Exiting Sherbet Land will put you back onto the Sherbet Land world spot.\
This is a side effect of the locked worlds code. Simply move left and then down to get to Mt. Teapot.

- The Jet powerup will let you dash without having the dash item.\
This is not the case for the Bull powerup.

- The lake in Parsley Woods 31 gets drained when Parsley Woods 32 is beaten.\
Some logical access might required the lake to still be there.\
In this case simply switch to a different savefile to grab the check.\
The same applies to Mt Teapot 13, which overwrites Mt Teapot 10 (and is unlocked by beating Mt. Teapot 12).

- Turning off autoscrollers messes with stage graphics and can lead to the cart stopping if it goes off screen.\
Use at your own risk.

- Overworld and Subworld movement will be activated once a connection to an Archipelago Server has been established.

## Blocksanity Tips

- In Blocksanity Parsley Woods 31 flooded and drained count as two different stages.

- You can use the following maps as a guideline, although some hidden blocks might be missing [VGMaps](https://vgmaps.com/Atlas/GB-GBC/index.htm#W)

- Stages contain hidden blocks that need to be jumped into from below.

- Rice Beach:
    - Rice Beach 1:  1 hidden block(s)
    - Rice Beach 2:  1 hidden block(s)
    - Rice Beach 3:  3 hidden block(s)
    - Rice Beach 5:  1 hidden block(s)
    - Rice Beach 6:  7 hidden block(s)
- Mt. Teapot:
    - Mt. Teapot 7:  18 hidden block(s)
    - Mt. Teapot 9:  1 hidden block(s)
    - Mt. Teapot 10: 3 hidden block(s)
    - Mt. Teapot 11: 1 hidden block(s)
- Sherbet Land:
    - Sherbet Land 14: 1 hidden block(s)
    - Sherbet Land 16: 1 hidden block(s)
    - Sherbet Land 17: 4 hidden block(s)
    - Sherbet Land 19: 3 hidden block(s)
- Stove Canyon:
    - Stove Canyon 20: 2 hidden block(s)
    - Stove Canyon 21: 2 hidden block(s)
    - Stove Canyon 22: 3 hidden block(s)
    - Stove Canyon 23: 1 hidden block(s)
- SS Teacup:
    - SS Teacup 26: 1 hidden block(s)
    - SS Teacup 27: 9 hidden block(s)
    - SS Teacup 28: 2 hidden block(s)
    - SS Teacup 30: 2 hidden block(s)
- Parsley Woods:
    - Parsley Woods 30: 1 hidden block(s)
- Syrup Castle
    - Syrup Castle 37: 1 hidden block(s)
    - Syrup Castle 39: 1 hidden block(s)
    - Syrup Castle 40: 5 hidden block(s)

## What does randomization do to this game?

The game starts with all worlds available (unless World Unlocks is activated).
The following unlock-items can be found in the multiworld:

Abilities:
- Climb
- Create Coin
- Dash
- Duck
- Highjump

Powerups:
- Garlic
- Bull
- Dragon
- Jet

Optional:
- World Unlocks
- Boss Unlocks

## What items and locations count as checks?

Every level exit is a check, optionally every treasure and/or face-block in the game can be turned into a check as well.\

## What other changes are made to the game?

Some quality of life improvements have been added to the game:

- Movement in the level-end screens have been sped up
- Some cutscenes have been removed from the game
- Autoscrollers can be turned into normal levels

==> worlds_wl-0.0.1.tar.gz: worlds_wl-0.0.1/src/worlds/wl/docs/en_Wario_Land.md <==
# Wario Land 1

## Where is the settings page?

You can read through all the settings and generate a YAML [here](../player-settings).

## Important things to note

- Exiting Sherbet Land will put you back onto the Sherbet Land world spot.\
This is a side effect of the locked worlds code. Simply move left and then down to get to Mt. Teapot.

- The Jet powerup will let you dash without having the dash item.\
This is not the case for the Bull powerup.

- The lake in Parsley Woods 31 gets drained when Parsley Woods 32 is beaten.\
Some logical access might required the lake to still be there.\
In this case simply switch to a different savefile to grab the check.\
The same applies to Mt Teapot 13, which overwrites Mt Teapot 10 (and is unlocked by beating Mt. Teapot 12).

- Turning off autoscrollers messes with stage graphics and can lead to the cart stopping if it goes off screen.\
Use at your own risk.

- Overworld and Subworld movement will be activated once a connection to a MultiworldGG Server has been established.

## Blocksanity Tips

- In Blocksanity Parsley Woods 31 flooded and drained count as two different stages.

- You can use the following maps as a guideline, although some hidden blocks might be missing [VGMaps](https://vgmaps.com/Atlas/GB-GBC/index.htm#W)

- Stages contain hidden blocks that need to be jumped into from below.

- Rice Beach:
    - Rice Beach 1:  1 hidden block(s)
    - Rice Beach 2:  1 hidden block(s)
    - Rice Beach 3:  3 hidden block(s)
    - Rice Beach 5:  1 hidden block(s)
    - Rice Beach 6:  7 hidden block(s)
- Mt. Teapot:
    - Mt. Teapot 7:  18 hidden block(s)
    - Mt. Teapot 9:  1 hidden block(s)
    - Mt. Teapot 10: 3 hidden block(s)
    - Mt. Teapot 11: 1 hidden block(s)
- Sherbet Land:
    - Sherbet Land 14: 1 hidden block(s)
    - Sherbet Land 16: 1 hidden block(s)
    - Sherbet Land 17: 4 hidden block(s)
    - Sherbet Land 19: 3 hidden block(s)
- Stove Canyon:
    - Stove Canyon 20: 2 hidden block(s)
    - Stove Canyon 21: 2 hidden block(s)
    - Stove Canyon 22: 3 hidden block(s)
    - Stove Canyon 23: 1 hidden block(s)
- SS Teacup:
    - SS Teacup 26: 1 hidden block(s)
    - SS Teacup 27: 9 hidden block(s)
    - SS Teacup 28: 2 hidden block(s)
    - SS Teacup 30: 2 hidden block(s)
- Parsley Woods:
    - Parsley Woods 30: 1 hidden block(s)
- Syrup Castle
    - Syrup Castle 37: 1 hidden block(s)
    - Syrup Castle 39: 1 hidden block(s)
    - Syrup Castle 40: 5 hidden block(s)

## What does randomization do to this game?

The game starts with all worlds available (unless World Unlocks is activated).
The following unlock-items can be found in the multiworld:

Abilities:
- Climb
- Create Coin
- Dash
- Duck
- Highjump

Powerups:
- Garlic
- Bull
- Dragon
- Jet

Optional:
- World Unlocks
- Boss Unlocks

## What items and locations count as checks?

Every level exit is a check, optionally every treasure and/or face-block in the game can be turned into a check as well.\

## What other changes are made to the game?

Some quality of life improvements have been added to the game:

- Movement in the level-end screens have been sped up
- Some cutscenes have been removed from the game
- Autoscrollers can be turned into normal levels
